@@ -1,10 +1,9 @@
 ;;; emacs-wiki-table.el --- Publish fancy tables
 
-;; Copyright (C) 2001, 2002, 2003 John Wiegley (johnw AT gnu DOT org)
+;; Copyright (C) 2001, 2002, 2003 John Wiegley
 
 ;; Emacs Lisp Archive Entry
 ;; Filename: emacs-wiki-table.el
-;; Version: 2.66
 ;; Keywords: hypermedia
 ;; Author: John Wiegley (johnw AT gnu DOT org)
 ;;         Alex Schroeder (alex AT gnu DOT org)
@@ -27,8 +26,8 @@
 ;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-;; MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -72,9 +71,11 @@
     (goto-char begin)
     (if (re-search-backward (concat "<p>["
                                     emacs-wiki-regexp-space
-                                    "]+" nil t))
+                                    "]+") nil t)
         (replace-match (if (>= (string-width leader) 6)
-                           "<center>\n"
+                           (if emacs-wiki-xhtml-inline-css
+                               "<span style=\"text-align:center;\">\n"
+                             "<center>\n")
                          (if (> (length leader) 0)
                              "<blockquote>\n"
                            ""))))
@@ -90,9 +91,11 @@
     (goto-char end)
     (if (re-search-forward (concat "["
                                    emacs-wiki-regexp-space
-                                   "]+</p>" nil t))
+                                   "]+</p>") nil t)
         (replace-match (if (>= (string-width leader) 6)
-                           "\n</center>"
+                           (if emacs-wiki-xhtml-inline-css
+                               "\n</span>"
+                             "\n</center>")
                          (if (> (length leader) 0)
                              "\n</blockquote>"
                            ""))))
